Search
===========

.. _search:

Introduction
------------
The search module contains functions for conducting searches against the Google Custom Search API, and then for parsing the results.

Usage
-----

To use the utils module:

.. code-block:: console

    >>> import coast_search
    >>> coast_search.search.function(to_use)

or:
.. code-block:: console

    >>> from coast_search import search
    >>> search.function(to_use)

Functions
---------

.. automodule:: coast_search.search
    :members:
    :undoc-members:
    :show-inheritance:
